<?php
/*
  Plugin Name: eMember Extra Login Shortcodes
  Version: v2.0
  Plugin URI: https://www.tipsandtricks-hq.com/wordpress-emember-easy-to-use-wordpress-membership-plugin-1706
  Author: Tips and Tricks HQ
  Author URI: https://www.tipsandtricks-hq.com/
  Description: It has a few nice looking emember login form shortcodes that you can use on your site.
 */

define( 'WP_EMEMBER_EXTRA_LOGIN_SHORTCODES_URL', plugins_url( '', __FILE__ ) );

if ( ! is_admin() ) {
    //Do these for front-end only
    add_action( 'wp_head', 'wp_eMember_extra_login_shortcodes_head_content' );
    add_action( 'wp_loaded', 'emember_login_shortcodes_wp_loaded_tasks' );

    add_shortcode( 'wp_eMember_fancy_login', 'wp_eMember_fancy_login_handler' );
    //2FA addon support
    add_filter( 'emem_2fa_form_output', 'wp_eMember_extra_login_shortcodes_2fa_form', 10, 7 );
}

function wp_eMember_extra_login_shortcodes_2fa_form( $out, $atts, $username, $pass, $remember_me, $errmsg, $member ) {
    extract( shortcode_atts( array(
	'style'				 => '1',
	'display_account_details'	 => '',
    ), $atts ) );
    if ( empty( $style ) ) {
	return $out;
    }
    $data		 = array(
	'username'	 => $username,
	'pass'		 => $pass,
	'remember_me'	 => $remember_me,
	'errmsg'	 => $errmsg,
	'style'		 => $style,
	'member'	 => $member
    );
    require_once(plugin_dir_path( __FILE__ ) . '2fa-forms.php');
    $twofa_forms	 = new eMember_fancy_login_2fa_support( $data );
    $res		 = $twofa_forms->show_2fa_form();
    return empty( $res ) ? $out : $res;
}

function wp_eMember_extra_login_shortcodes_head_content() {
    echo '<link type="text/css" rel="stylesheet" href="' . WP_EMEMBER_EXTRA_LOGIN_SHORTCODES_URL . '/css/eMember_extra_login_shortcodes_style.css" />' . "\n";
}

function emember_login_shortcodes_wp_loaded_tasks() {
    //Sanitize and/or initialize the inputs. Do this AFTER plugins_loaded so emember's empty username/password check doesn't get triggered
    $_POST[ 'login_user_name' ]	 = (isset( $_POST[ 'login_user_name' ] )) ? sanitize_text_field( $_POST[ 'login_user_name' ] ) : '';
    $_POST[ 'login_pwd' ]		 = (isset( $_POST[ 'login_pwd' ] )) ? sanitize_text_field( $_POST[ 'login_pwd' ] ) : '';
}

function wp_eMember_fancy_login_handler( $atts ) {
    extract( shortcode_atts( array(
	'style'				 => '1',
	'display_account_details'	 => '',
    ), $atts ) );

    if ( $style == '1' ) {
	return eMember_fancy_login_1( $display_account_details );
    } else if ( $style == '2' ) {
	return eMember_fancy_login_2( $display_account_details );
    } else if ( $style == '3' ) {
	return eMember_fancy_login_3( $display_account_details );
    } else if ( $style == '4' ) {
	return eMember_fancy_login_4( $display_account_details );
    } else if ( $style == '5' ) {
	return eMember_fancy_login_5( $display_account_details );
    } else if ( $style == '6' ) {
	return eMember_fancy_login_6( $display_account_details );
    } else if ( $style == '7' ) {
	return eMember_fancy_login_7( $display_account_details );
    } else if ( $style == '8' ) {
	return eMember_fancy_login_8( $display_account_details );
    }

    // If no match, display the fancy compact login.
    return eMember_fancy_login_1( $display_account_details );
}

function eMember_fancy_login_1( $display_account_details = '' ) {
    $emember_config	 = Emember_Config::getInstance();
    $emember_auth	 = Emember_Auth::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output	 = '<div class="eMember_fancy_login_1">';
    $output	 .= '<ul>';

    if ( $emember_auth->isLoggedIn() ) {

	//Show the compact one.
	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';
    } else {
	if ( is_search() ) {
	    return get_login_link();
	}

	$login_url	 = $emember_config->getValue( 'login_page_url' );
	$output		 .= '<li><a href="' . $login_url . '">' . EMEMBER_LOGIN . '</a></li>';

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
    }

    $output .= "</ul></div>";

    return $output;
}

function eMember_fancy_login_2( $display_account_details = '' ) {
    global $emember_auth;
    global $emember_config;
    $emember_auth	 = Emember_Auth::getInstance();
    $emember_config	 = Emember_Config::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output = '<div class="eMember_fancy_login_2">';

    if ( $emember_auth->isLoggedIn() ) {
	$output .= '<div class="eMember_fancy_login_2_account_details">';

	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<ul>';
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';

	$output	 .= '</ul>';
	$output	 .= '</div>';
    } else {
	$widget_title = $emember_config->getValue( 'wp_eMember_widget_title' );
	if ( empty( $widget_title ) ) {
	    $widget_title = EMEMBER_MEMBER_LOGIN;
	}

	$output	 .= '<h3>' . $widget_title . '</h3>';
	$output	 .= '<form action="" method="post">';
	$output	 .= wp_nonce_field( 'emember-login-nonce', '_wpnonce', true, false );
	if ( empty( $_POST[ 'login_user_name' ] ) ) {
	    $default_username = EMEMBER_USER_NAME;
	} else {
	    $default_username = $_POST[ 'login_user_name' ];
	}

	$output .= '<input type="text" name="login_user_name" size="17" value="' . $default_username . '" class="fancy_login_2_username" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	if ( empty( $_POST[ 'login_pwd' ] ) ) {
	    $default_password = "XXXXXXXX";
	} else {
	    $default_password = $_POST[ 'login_pwd' ];
	}

	$output .= '<input type="password" name="login_pwd" size="17" value="' . $default_password . '" class="fancy_login_2_password" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	$output	 .= '<div class="eMember_fancy_login_2_rememberme">';
	$output	 .= '<input type="checkbox" value="forever" id="rememberme" name="rememberme" />';
	$output	 .= '<label class="eMember_fancy_login_2_rememberme_label">' . EMEMBER_REMEMBER_ME . '</label>';
	$output	 .= '</div>';

	$output	 .= '<input name="doLogin" type="submit" id="doLogin" value="' . EMEMBER_LOGIN . '">';
	$output	 .= '</form>';

	$msg	 = $emember_auth->getSavedMessage( 'eMember_login_status_msg' );
	$output	 .= '<span class="emember_error">' . $msg . '</span>';

	$output .= '<ul>';

	$password_reset_url = $emember_config->getValue( 'eMember_password_reset_page' );
	if ( $password_reset_url ) {
	    $output .= '<li><a href="' . $password_reset_url . '">' . EMEMBER_FORGOT_PASS . '</a></li>';
	} else {
	    $output .= '<li><a id="forgot_pass" rel="#emember_forgot_pass_prompt" class="forgot_pass_link" href="javascript:void(0);">' . EMEMBER_FORGOT_PASS . '</li></a>';
	}

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a id="register" class="register_link" href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
	$output		 .= '</ul>';
    }

    $output .= "</div>";

    return $output;
}

function eMember_fancy_login_3( $display_account_details = '' ) {
    global $emember_auth;
    global $emember_config;
    $emember_auth	 = Emember_Auth::getInstance();
    $emember_config	 = Emember_Config::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output = '<div class="eMember_fancy_login_3">';

    if ( $emember_auth->isLoggedIn() ) {
	$output .= '<div class="eMember_fancy_login_3_account_details">';

	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<ul>';
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';

	$output	 .= '</ul>';
	$output	 .= '</div>';
    } else {
	$widget_title = $emember_config->getValue( 'wp_eMember_widget_title' );
	if ( empty( $widget_title ) ) {
	    $widget_title = EMEMBER_MEMBER_LOGIN;
	}

	$output	 .= '<h3>' . $widget_title . '</h3>';
	$output	 .= '<form action="" method="post">';
	$output	 .= wp_nonce_field( 'emember-login-nonce', '_wpnonce', true, false );
	if ( empty( $_POST[ 'login_user_name' ] ) ) {
	    $default_username = EMEMBER_USER_NAME;
	} else {
	    $default_username = $_POST[ 'login_user_name' ];
	}

	$output .= '<input type="text" name="login_user_name" size="17" value="' . $default_username . '" class="fancy_login_3_username" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	if ( empty( $_POST[ 'login_pwd' ] ) ) {
	    $default_password = "XXXXXXXX";
	} else {
	    $default_password = $_POST[ 'login_pwd' ];
	}

	$output .= '<input type="password" name="login_pwd" size="17" value="' . $default_password . '" class="fancy_login_3_password" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	$output	 .= '<div class="eMember_fancy_login_3_rememberme">';
	$output	 .= '<input type="checkbox" value="forever" id="rememberme" name="rememberme" />';
	$output	 .= '<label class="eMember_fancy_login_3_rememberme_label">' . EMEMBER_REMEMBER_ME . '</label>';
	$output	 .= '</div>';

	$output	 .= '<input name="doLogin" type="submit" id="doLogin" value="' . EMEMBER_LOGIN . '">';
	$output	 .= '</form>';

	$msg	 = $emember_auth->getSavedMessage( 'eMember_login_status_msg' );
	$output	 .= '<span class="emember_error">' . $msg . '</span>';

	$output .= '<ul>';

	$password_reset_url = $emember_config->getValue( 'eMember_password_reset_page' );
	if ( $password_reset_url ) {
	    $output .= '<li><a href="' . $password_reset_url . '">' . EMEMBER_FORGOT_PASS . '</a></li>';
	} else {
	    $output .= '<li><a id="forgot_pass" rel="#emember_forgot_pass_prompt" class="forgot_pass_link" href="javascript:void(0);">' . EMEMBER_FORGOT_PASS . '</li></a>';
	}

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a id="register" class="register_link" href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
	$output		 .= '</ul>';
    }

    $output .= "</div>";

    return $output;
}

function eMember_fancy_login_4( $display_account_details = '' ) {
    global $emember_auth;
    global $emember_config;
    $emember_auth	 = Emember_Auth::getInstance();
    $emember_config	 = Emember_Config::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output = '<div class="eMember_fancy_login_4">';

    if ( $emember_auth->isLoggedIn() ) {
	$output .= '<div class="eMember_fancy_login_4_account_details">';

	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<ul>';
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';

	$output	 .= '</ul>';
	$output	 .= '</div>';
    } else {
	$widget_title = $emember_config->getValue( 'wp_eMember_widget_title' );
	if ( empty( $widget_title ) ) {
	    $widget_title = EMEMBER_MEMBER_LOGIN;
	}

	$output	 .= '<h3>' . $widget_title . '</h3>';
	$output	 .= '<form action="" method="post">';
	$output	 .= wp_nonce_field( 'emember-login-nonce', '_wpnonce', true, false );
	if ( empty( $_POST[ 'login_user_name' ] ) ) {
	    $default_username = EMEMBER_USER_NAME;
	} else {
	    $default_username = $_POST[ 'login_user_name' ];
	}

	$output .= '<input type="text" name="login_user_name" size="17" value="' . $default_username . '" class="fancy_login_4_username" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	if ( empty( $_POST[ 'login_pwd' ] ) ) {
	    $default_password = "XXXXXXXX";
	} else {
	    $default_password = $_POST[ 'login_pwd' ];
	}

	$output .= '<input type="password" name="login_pwd" size="17" value="' . $default_password . '" class="fancy_login_4_password" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	$output	 .= '<div class="eMember_fancy_login_4_rememberme">';
	$output	 .= '<input type="checkbox" value="forever" id="rememberme" name="rememberme" />';
	$output	 .= '<label class="eMember_fancy_login_4_rememberme_label">' . EMEMBER_REMEMBER_ME . '</label>';
	$output	 .= '</div>';

	$output	 .= '<input name="doLogin" type="submit" id="doLogin" value="' . EMEMBER_LOGIN . '">';
	$output	 .= '</form>';

	$msg	 = $emember_auth->getSavedMessage( 'eMember_login_status_msg' );
	$output	 .= '<span class="emember_error">' . $msg . '</span>';

	$output .= '<ul>';

	$password_reset_url = $emember_config->getValue( 'eMember_password_reset_page' );
	if ( $password_reset_url ) {
	    $output .= '<li><a href="' . $password_reset_url . '">' . EMEMBER_FORGOT_PASS . '</a></li>';
	} else {
	    $output .= '<li><a id="forgot_pass" rel="#emember_forgot_pass_prompt" class="forgot_pass_link" href="javascript:void(0);">' . EMEMBER_FORGOT_PASS . '</li></a>';
	}

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a id="register" class="register_link" href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
	$output		 .= '</ul>';
    }

    $output .= "</div>";

    return $output;
}

function eMember_fancy_login_5( $display_account_details = '' ) {
    global $emember_auth;
    global $emember_config;
    $emember_auth	 = Emember_Auth::getInstance();
    $emember_config	 = Emember_Config::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output = '<div class="eMember_fancy_login_5">';

    if ( $emember_auth->isLoggedIn() ) {
	$output .= '<div class="eMember_fancy_login_5_account_details">';

	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<ul>';
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';

	$output	 .= '</ul>';
	$output	 .= '</div>';
    } else {
	$widget_title = $emember_config->getValue( 'wp_eMember_widget_title' );
	if ( empty( $widget_title ) ) {
	    $widget_title = EMEMBER_MEMBER_LOGIN;
	}

	$output	 .= '<h3>' . $widget_title . '</h3>';
	$output	 .= '<form action="" method="post">';
	$output	 .= wp_nonce_field( 'emember-login-nonce', '_wpnonce', true, false );
	if ( empty( $_POST[ 'login_user_name' ] ) ) {
	    $default_username = EMEMBER_USER_NAME;
	} else {
	    $default_username = $_POST[ 'login_user_name' ];
	}

	$output .= '<input type="text" name="login_user_name" size="17" value="' . $default_username . '" class="fancy_login_5_username" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	if ( empty( $_POST[ 'login_pwd' ] ) ) {
	    $default_password = "XXXXXXXX";
	} else {
	    $default_password = $_POST[ 'login_pwd' ];
	}

	$output .= '<input type="password" name="login_pwd" size="17" value="' . $default_password . '" class="fancy_login_5_password" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	$output	 .= '<div class="eMember_fancy_login_5_rememberme">';
	$output	 .= '<input type="checkbox" value="forever" id="rememberme" name="rememberme" />';
	$output	 .= '<label class="eMember_fancy_login_5_rememberme_label">' . EMEMBER_REMEMBER_ME . '</label>';
	$output	 .= '</div>';

	$output	 .= '<input name="doLogin" type="submit" id="doLogin" value="' . EMEMBER_LOGIN . '">';
	$output	 .= '</form>';

	$msg	 = $emember_auth->getSavedMessage( 'eMember_login_status_msg' );
	$output	 .= '<span class="emember_error">' . $msg . '</span>';

	$output .= '<ul>';

	$password_reset_url = $emember_config->getValue( 'eMember_password_reset_page' );
	if ( $password_reset_url ) {
	    $output .= '<li><a href="' . $password_reset_url . '">' . EMEMBER_FORGOT_PASS . '</a></li>';
	} else {
	    $output .= '<li><a id="forgot_pass" rel="#emember_forgot_pass_prompt" class="forgot_pass_link" href="javascript:void(0);">' . EMEMBER_FORGOT_PASS . '</li></a>';
	}

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a id="register" class="register_link" href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
	$output		 .= '</ul>';
    }

    $output .= "</div>";

    return $output;
}

function eMember_fancy_login_6( $display_account_details = '' ) {
    global $emember_auth;
    global $emember_config;
    $emember_auth	 = Emember_Auth::getInstance();
    $emember_config	 = Emember_Config::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output = '<div class="eMember_fancy_login_6">';

    if ( $emember_auth->isLoggedIn() ) {
	$output .= '<div class="eMember_fancy_login_6_account_details">';

	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<ul>';
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';

	$output	 .= '</ul>';
	$output	 .= '</div>';
    } else {
	$widget_title = $emember_config->getValue( 'wp_eMember_widget_title' );
	if ( empty( $widget_title ) ) {
	    $widget_title = EMEMBER_MEMBER_LOGIN;
	}

	$output	 .= '<h3>' . $widget_title . '</h3>';
	$output	 .= '<form action="" method="post">';
	$output	 .= wp_nonce_field( 'emember-login-nonce', '_wpnonce', true, false );
	if ( empty( $_POST[ 'login_user_name' ] ) ) {
	    $default_username = EMEMBER_USER_NAME;
	} else {
	    $default_username = $_POST[ 'login_user_name' ];
	}

	$output .= '<input type="text" name="login_user_name" size="17" value="' . $default_username . '" class="fancy_login_6_username" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	if ( empty( $_POST[ 'login_pwd' ] ) ) {
	    $default_password = "XXXXXXXX";
	} else {
	    $default_password = $_POST[ 'login_pwd' ];
	}

	$output .= '<input type="password" name="login_pwd" size="17" value="' . $default_password . '" class="fancy_login_6_password" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	$output	 .= '<div class="eMember_fancy_login_6_rememberme">';
	$output	 .= '<input type="checkbox" value="forever" id="rememberme" name="rememberme" />';
	$output	 .= '<label class="eMember_fancy_login_6_rememberme_label">' . EMEMBER_REMEMBER_ME . '</label>';
	$output	 .= '</div>';

	$output	 .= '<input name="doLogin" type="submit" id="doLogin" value="' . EMEMBER_LOGIN . '">';
	$output	 .= '</form>';

	$msg	 = $emember_auth->getSavedMessage( 'eMember_login_status_msg' );
	$output	 .= '<span class="emember_error">' . $msg . '</span>';

	$output .= '<ul>';

	$password_reset_url = $emember_config->getValue( 'eMember_password_reset_page' );
	if ( $password_reset_url ) {
	    $output .= '<li><a href="' . $password_reset_url . '">' . EMEMBER_FORGOT_PASS . '</a></li>';
	} else {
	    $output .= '<li><a id="forgot_pass" rel="#emember_forgot_pass_prompt" class="forgot_pass_link" href="javascript:void(0);">' . EMEMBER_FORGOT_PASS . '</li></a>';
	}

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a id="register" class="register_link" href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
	$output		 .= '</ul>';
    }

    $output .= "</div>";

    return $output;
}

function eMember_fancy_login_7( $display_account_details = '' ) {
    global $emember_auth;
    global $emember_config;
    $emember_auth	 = Emember_Auth::getInstance();
    $emember_config	 = Emember_Config::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output = '<div class="eMember_fancy_login_7">';

    if ( $emember_auth->isLoggedIn() ) {
	$output .= '<div class="eMember_fancy_login_7_account_details">';

	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<ul>';
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';

	$output	 .= '</ul>';
	$output	 .= '</div>';
    } else {
	$widget_title = $emember_config->getValue( 'wp_eMember_widget_title' );
	if ( empty( $widget_title ) ) {
	    $widget_title = EMEMBER_MEMBER_LOGIN;
	}

	$output	 .= '<h3>' . $widget_title . '</h3>';
	$output	 .= '<form action="" method="post">';
	$output	 .= wp_nonce_field( 'emember-login-nonce', '_wpnonce', true, false );
	if ( empty( $_POST[ 'login_user_name' ] ) ) {
	    $default_username = EMEMBER_USER_NAME;
	} else {
	    $default_username = $_POST[ 'login_user_name' ];
	}

	$output .= '<input type="text" name="login_user_name" size="17" value="' . $default_username . '" class="fancy_login_7_username" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	if ( empty( $_POST[ 'login_pwd' ] ) ) {
	    $default_password = "XXXXXXXX";
	} else {
	    $default_password = $_POST[ 'login_pwd' ];
	}

	$output .= '<input type="password" name="login_pwd" size="17" value="' . $default_password . '" class="fancy_login_7_password" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';

	$output	 .= '<div class="eMember_fancy_login_7_rememberme">';
	$output	 .= '<input type="checkbox" value="forever" id="rememberme" name="rememberme" />';
	$output	 .= '<label class="eMember_fancy_login_7_rememberme_label">' . EMEMBER_REMEMBER_ME . '</label>';
	$output	 .= '</div>';

	$output	 .= '<div class="eMember_fancy_login_7_submit">';
	$output	 .= '<input name="doLogin" type="submit" id="doLogin" value="' . EMEMBER_LOGIN . '">';
	$output	 .= '</div>';
	$output	 .= '</form>';

	$output	 .= '<div class="eMember_fancy_login_7_msg">';
	$msg	 = $emember_auth->getSavedMessage( 'eMember_login_status_msg' );
	$output	 .= '<span class="emember_error">' . $msg . '</span>';
	$output	 .= '</div>';

	$output .= '<ul>';

	$password_reset_url = $emember_config->getValue( 'eMember_password_reset_page' );
	if ( $password_reset_url ) {
	    $output .= '<li><a href="' . $password_reset_url . '">' . EMEMBER_FORGOT_PASS . '</a></li>';
	} else {
	    $output .= '<li><a id="forgot_pass" rel="#emember_forgot_pass_prompt" class="forgot_pass_link" href="javascript:void(0);">' . EMEMBER_FORGOT_PASS . '</li></a>';
	}

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a id="register" class="register_link" href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
	$output		 .= '</ul>';
    }

    $output .= "</div>";

    return $output;
}

function eMember_fancy_login_8( $display_account_details = '' ) {
    global $emember_auth;
    global $emember_config;
    $emember_auth	 = Emember_Auth::getInstance();
    $emember_config	 = Emember_Config::getInstance();

    if ( $emember_auth->isLoggedIn() && ! empty( $display_account_details ) ) {
	//Show the detailed logged-in widget.
	$output = eMember_display_account_details();
	return $output;
    }

    $output = '<div class="eMember_fancy_login_8">';

    if ( $emember_auth->isLoggedIn() ) {
	$output .= '<div class="eMember_fancy_login_8_account_details">';

	$name	 = $emember_auth->getUserInfo( 'first_name' ) . " " . $emember_auth->getUserInfo( 'last_name' );
	$output	 .= '<ul>';
	$output	 .= '<li class="eMember_fancy_login_bold">' . $name . '</li>';

	$edit_profile_page = $emember_config->getValue( 'eMember_profile_edit_page' );

	if ( ! empty( $edit_profile_page ) ) {
	    $output .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
	}

	$logout	 = get_logout_url();
	$output	 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';

	$output	 .= '</ul>';
	$output	 .= '</div>';
    } else {
	$output .= '<div class="eMember_fancy_login_8_inner">';

	$widget_title = $emember_config->getValue( 'wp_eMember_widget_title' );
	if ( empty( $widget_title ) ) {
	    $widget_title = EMEMBER_MEMBER_LOGIN;
	}

	$output	 .= '<h3>' . $widget_title . '</h3>';
	$output	 .= '<form action="" method="post">';
	$output	 .= wp_nonce_field( 'emember-login-nonce', '_wpnonce', true, false );
	$output	 .= '<div class="eMember_fancy_login_8_input_block">';
	$output	 .= '<label>' . EMEMBER_USER_NAME . '</label>';
	$output	 .= '<input type="text" name="login_user_name" size="17" value="' . $_POST[ 'login_user_name' ] . '" class="fancy_login_8_username" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';
	$output	 .= '</div>';

	$output	 .= '<div class="eMember_fancy_login_8_input_block">';
	$output	 .= '<label>' . EMEMBER_PASSWORD . '</label>';
	$output	 .= '<input type="password" name="login_pwd" size="17" value="' . $_POST[ 'login_pwd' ] . '" class="fancy_login_8_password" onfocus="if(this.value==this.defaultValue)this.value=\'\';" onblur="if(this.value==\'\')this.value=this.defaultValue;">';
	$output	 .= '</div>';

	$output	 .= '<div class="eMember_fancy_login_8_rememberme">';
	$output	 .= '<input type="checkbox" value="forever" id="rememberme" name="rememberme" />';
	$output	 .= '<label class="eMember_fancy_login_8_rememberme_label">' . EMEMBER_REMEMBER_ME . '</label>';
	$output	 .= '</div>';

	$output	 .= '<input name="doLogin" type="submit" id="doLogin" value="' . EMEMBER_LOGIN . '">';
	$output	 .= '</form>';

	$msg	 = $emember_auth->getSavedMessage( 'eMember_login_status_msg' );
	$output	 .= '<span class="emember_error">' . $msg . '</span>';

	$output .= '<ul>';

	$password_reset_url = $emember_config->getValue( 'eMember_password_reset_page' );
	if ( $password_reset_url ) {
	    $output .= '<li><a href="' . $password_reset_url . '">' . EMEMBER_FORGOT_PASS . '</a></li>';
	} else {
	    $output .= '<li><a id="forgot_pass" rel="#emember_forgot_pass_prompt" class="forgot_pass_link" href="javascript:void(0);">' . EMEMBER_FORGOT_PASS . '</li></a>';
	}

	$join_url	 = $emember_config->getValue( 'eMember_payments_page' );
	$output		 .= '<li><a id="register" class="register_link" href="' . $join_url . '">' . EMEMBER_JOIN . '</a></li>';
	$output		 .= '</ul>';
	$output		 .= "</div>";
    }

    $output .= "</div>";

    return $output;
}

function eMember_display_account_details() {

    if ( ! defined( 'DONOTCACHEPAGE' ) ) {
	define( 'DONOTCACHEPAGE', TRUE ); //Cache plugin compatibility. Do not cache the login form.
    }

    $emember_config	 = Emember_Config::getInstance();
    $auth		 = Emember_Auth::getInstance();
    $username	 = $auth->getUserInfo( 'user_name' );
    $output		 = '';

    if ( ! $auth->isLoggedIn() ) {
	return '';
    }

    $expires		 = $auth->getUserInfo( 'account_state' );
    $subscription_duration	 = $auth->permitted->subscription_duration;
    if ( $subscription_duration[ 'type' ] == 'noexpire' ) {
	$sub_expires = EMEMBER_NEVER;
    } else if ( $subscription_duration[ 'type' ] == 'fixeddate' ) {
	$expiry_date	 = $subscription_duration[ 'duration' ]; //For fixed date expiry, the duration field contains the expiry date.
	$sub_expires	 = emember_get_formatted_date_according_to_wp_settings( $expiry_date );
    } else {
	//Create date object with start date
	$start_date	 = $auth->getUserInfo( 'subscription_starts' );
	$date_obj	 = new DateTime( $start_date );

	//Create the interval object using the subscription duration value.
	$interval_string = 'P' . $subscription_duration[ 'duration' ] . 'D'; //Example - 30 days will be P30D
	$interval	 = new DateInterval( $interval_string );

	//Add them
	$date_obj->add( $interval );

	//Create the formatted date output
	$expiry_date	 = $date_obj->format( 'Y-m-d' );
	$sub_expires	 = emember_get_formatted_date_according_to_wp_settings( $expiry_date );
    }

    $states				 = array( 'active'	 => EMEMBER_ACTIVE,
	'inactive'	 => EMEMBER_INACTIVE,
	'expired'	 => EMEMBER_EXPIRED,
	'pending'	 => EMEMBER_PENDING,
	'unsubscribed'	 => EMEMBER_UNSUBSCRIBED );
    $eMember_secure_rss		 = $emember_config->getValue( 'eMember_secure_rss' );
    $eMember_show_welcome_page_link	 = $emember_config->getValue( 'eMember_show_link_to_after_login_page' );
    $feed_url			 = get_bloginfo( 'rss2_url' );

    global $wp_rewrite;
    //$nonce = wp_create_nonce('emember-secure-feed-nonce');
    if ( $wp_rewrite->using_permalinks() ) {
	$feed_url .= '?emember_feed_key=' . md5( $auth->getUserInfo( 'member_id' ) );
    } else {
	$feed_url .= '&emember_feed_key=' . md5( $auth->getUserInfo( 'member_id' ) );
    }

    $logout	 = get_logout_url();
    $output	 .= '<div class="eMember_logged_widget">';
    $output	 .= '<div class="eMember_logged_user_info_section">';
    $output	 .= '<div class="eMember_logged_in_as">' . EMEMBER_LOGGED_IN_AS;
    $output	 .= '<label class="eMember_highlight">' . $username . '</label></div>';
    $output	 .= '<div class="eMember_logged_in_level">' . EMEMBER_LOGGED_IN_LEVEL;
    $output	 .= '<label class="eMember_highlight">' . $auth->permitted->primary_level->get( 'alias' ) . '</label></div>';
    $output	 .= '<div class="eMember_logged_in_account_status">' . EMEMBER_ACCOUNT_STATUS . " ";
    $output	 .= '<label class="eMember_highlight">' . $states[ $auth->getUserInfo( 'account_state' ) ] . '</label></div>';
    $output	 .= '<div class="eMember_logged_user_expiry">';
    if ( $expires != 'expired' ) {
	$output	 .= EMEMBER_ACCOUNT_EXPIRES_ON . " ";
	$output	 .= '<label class="eMember_highlight">' . $sub_expires . '</label>';
    } else {
	$renew_url	 = $emember_config->getValue( 'eMember_account_upgrade_url' );
	$output		 .= '<a href="' . $renew_url . '">' . EMEMBER_RENEW_OR_UPGRADE . '</a>';
    }
    $output .= '</div>'; //End of eMember_logged_user_expiry

    $output			 .= '</div>'; //End of eMember_logged_user_info_section
    $output			 .= '<ul>';
    $output			 .= '<li><a href="' . $logout . '">' . EMEMBER_LOGOUT . '</a></li>';
    if ( $eMember_secure_rss )
	$output			 .= '<li><a href="' . $feed_url . '">' . EMEMBER_MY_FEED . '</a></li>';
    $edit_profile_page	 = $emember_config->getValue( 'eMember_profile_edit_page' );
    $support_page		 = $emember_config->getValue( 'eMember_support_page' );
    if ( ! empty( $edit_profile_page ) )
	$output			 .= '<li><a href="' . $edit_profile_page . '">' . EMEMBER_EDIT_PROFILE . '</a></li>';
    if ( ! empty( $support_page ) )
	$output			 .= '<li><a href="' . $support_page . '">' . EMEMBER_SUPPORT_PAGE . '</a></li>';
    if ( $eMember_show_welcome_page_link ) {
	$welcome_page_url	 = emember_get_after_login_page_url_of_current_user();
	$output			 .= '<li><a href="' . $welcome_page_url . '">' . EMEMBER_WELCOME_PAGE . '</a></li>';
    }
    $bookmark_feature = $emember_config->getValue( 'eMember_enable_bookmark' );
    if ( $bookmark_feature ) {
	$bookmark_page_url	 = $emember_config->getValue( 'eMember_bookmark_listing_page' );
	if ( ! empty( $bookmark_page_url ) )
	    $output			 .= '<li><a href="' . $bookmark_page_url . '">' . EMEMBER_BOOKMARK_PAGE . '</a></li>';
    }
    $output			 .= '</ul>';
    $custom_login_msg	 = stripslashes( $emember_config->getValue( 'eMember_login_widget_message_for_logged_members' ) );
    if ( ! empty( $custom_login_msg ) ) {
	$custom_login_msg	 = do_shortcode( $custom_login_msg );
	$output			 .= html_entity_decode( $custom_login_msg, ENT_COMPAT );
    }
    $output .= '</div>'; //End of eMember_logged_widget

    return $output;
}
